@@ -21,6 +21,8 @@ Example
 
 """
 
+import warnings
+
 from flask import Blueprint as FlaskBlueprint
 from flask_via import RoutesImporter
 from flask_via.routers import BaseRouter
@@ -118,6 +120,19 @@ class Basic(Functional):
     .. deprecated:: 2014.05.19
     """
 
+    def __init__(self, *args, **kwargs):
+        """ Issues ``DeprecationWarning`` as this is deprecated and will be
+        removed in a later version.
+        """
+
+        warnings.simplefilter('always', DeprecationWarning)
+        warnings.warn(
+            'Basic router will be removed in a future version, please switch '
+            'to the Functional router.',
+            DeprecationWarning)
+
+        super(Basic, self).__init__(*args, **kwargs)
+
 
 class Pluggable(BaseRouter):
     """ Pluggable View router class, allows Flask pluggable view routes to be
@@ -400,7 +415,7 @@ class Blueprint(BaseRouter, RoutesImporter):
         routes = self.include(self.routes_module, self.routes_name)
 
         # Load the routes
-        self.load(blueprint, routes)
+        self.load(blueprint, routes, **kwargs)
 
         # Register the blueprint with the application
         app.register_blueprint(blueprint)
